@@ -113,36 +113,36 @@ void SQ_ImageFilter::init()
 
 void SQ_ImageFilter::slotStartFiltering()
 {
-    SQ_Config *kconf = SQ_Config::instance();
+    SQ_Config *tdeconf = SQ_Config::instance();
 
-    kconf->setGroup("Image edit options");
-    kconf->writeEntry("filter_swapRGB", buttonGroupSwapRGB->selectedId());
-    kconf->writeEntry("filter_blend_color", pushBlendColor->color().name());
-    kconf->writeEntry("filter_blend_opacity", blendOpacity->value());
-    kconf->writeEntry("filter_fade_color", fadeColor->color().name());
-    kconf->writeEntry("filter_fade_value", fadeValue->value());
-    kconf->writeEntry("filter_desaturate_value", desaturateValue->value());
-    kconf->writeEntry("filter_threshold_value", thresholdValue->value());
-    kconf->writeEntry("filter_threshold_redeye", thresholdRE->value());
-    kconf->writeEntry("filter_solarize_value", solarizeValue->value());
-    kconf->writeEntry("filter_spread_value", spreadValue->value());
-    kconf->writeEntry("filter_swirl_value", swirlAngle->value());
-    kconf->writeEntry("filter_noise", buttonGroupNoise->selectedId());
-    kconf->writeEntry("filter_flatten_color1", flattenColor1->color().name());
-    kconf->writeEntry("filter_flatten_color2", flattenColor2->color().name());
-    kconf->writeEntry("filter_shade_azim", shadeAzim->value());
-    kconf->writeEntry("filter_shade_elev", shadeElev->value());
-    kconf->writeEntry("filter_shade_color", shadeColor->isChecked());
-    kconf->writeEntry("filter_blur_radius", blurRadius->value());
-    kconf->writeEntry("filter_blur_sigma", blurSigma->value());
-    kconf->writeEntry("filter_implode_factor", implodeFactor->value());
-    kconf->writeEntry("filter_egde_radius", edgeRadius->value());
-    kconf->writeEntry("filter_emboss_radius", embossRadius->value());
-    kconf->writeEntry("filter_emboss_sigma", embossSigma->value());
-    kconf->writeEntry("filter_sharpen_radius", sharpenRadius->value());
-    kconf->writeEntry("filter_sharpen_sigma", sharpenSigma->value());
-    kconf->writeEntry("filter_oil_radius", oilRadius->value());
-    kconf->writeEntry("filter_filter", listMain->currentItem());
+    tdeconf->setGroup("Image edit options");
+    tdeconf->writeEntry("filter_swapRGB", buttonGroupSwapRGB->selectedId());
+    tdeconf->writeEntry("filter_blend_color", pushBlendColor->color().name());
+    tdeconf->writeEntry("filter_blend_opacity", blendOpacity->value());
+    tdeconf->writeEntry("filter_fade_color", fadeColor->color().name());
+    tdeconf->writeEntry("filter_fade_value", fadeValue->value());
+    tdeconf->writeEntry("filter_desaturate_value", desaturateValue->value());
+    tdeconf->writeEntry("filter_threshold_value", thresholdValue->value());
+    tdeconf->writeEntry("filter_threshold_redeye", thresholdRE->value());
+    tdeconf->writeEntry("filter_solarize_value", solarizeValue->value());
+    tdeconf->writeEntry("filter_spread_value", spreadValue->value());
+    tdeconf->writeEntry("filter_swirl_value", swirlAngle->value());
+    tdeconf->writeEntry("filter_noise", buttonGroupNoise->selectedId());
+    tdeconf->writeEntry("filter_flatten_color1", flattenColor1->color().name());
+    tdeconf->writeEntry("filter_flatten_color2", flattenColor2->color().name());
+    tdeconf->writeEntry("filter_shade_azim", shadeAzim->value());
+    tdeconf->writeEntry("filter_shade_elev", shadeElev->value());
+    tdeconf->writeEntry("filter_shade_color", shadeColor->isChecked());
+    tdeconf->writeEntry("filter_blur_radius", blurRadius->value());
+    tdeconf->writeEntry("filter_blur_sigma", blurSigma->value());
+    tdeconf->writeEntry("filter_implode_factor", implodeFactor->value());
+    tdeconf->writeEntry("filter_egde_radius", edgeRadius->value());
+    tdeconf->writeEntry("filter_emboss_radius", embossRadius->value());
+    tdeconf->writeEntry("filter_emboss_sigma", embossSigma->value());
+    tdeconf->writeEntry("filter_sharpen_radius", sharpenRadius->value());
+    tdeconf->writeEntry("filter_sharpen_sigma", sharpenSigma->value());
+    tdeconf->writeEntry("filter_oil_radius", oilRadius->value());
+    tdeconf->writeEntry("filter_filter", listMain->currentItem());
 
     SQ_ImageFilterOptions opt;
  
