@@ -438,7 +438,7 @@ static void HorizontalFilter(const TQImage& source,TQImage& destination,
     stop,
     y;
 
-  register long
+  long
     i,
     x;
 
@@ -523,7 +523,7 @@ static void VerticalFilter(const TQImage& source,TQImage& destination,
     stop,
     x;
 
-  register long
+  long
     i,
     y;
 
@@ -737,13 +737,13 @@ TQImage SampleImage(const TQImage& image,const int columns,
   uchar
     *pixels;
 
-  register const uchar
+  const uchar
     *p;
 
-  register long
+  long
     x;
 
-  register uchar
+  uchar
     *q;
 
   /*
